Package: a4Classif
Type: Package
Title: Automated Affymetrix Array Analysis Classification Package
Version: 1.60.0
Date: 2021-07-13
Authors@R: c(
  person(given = "Willem", family = "Talloen", role = "aut"),
  person(given = "Tobias", family = "Verbeke", role = "aut", email = "tobias.verbeke@openanalytics.eu"),
  person(given = "Laure", family = "Cougnaud", role = "cre", email = "laure.cougnaud@openanalytics.eu")
 )
Description: Functionalities for classification of Affymetrix
        microarray data, integrating within the Automated Affymetrix
        Array Analysis set of packages.
Depends: a4Core, a4Preproc
Imports: methods, Biobase, ROCR, pamr, glmnet, varSelRF, utils,
        graphics, stats
Suggests: ALL, hgu95av2.db, knitr, rmarkdown
License: GPL-3
biocViews: Microarray, GeneExpression, Classification
VignetteBuilder: knitr
RoxygenNote: 7.1.1
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 12:35:22 UTC
RemoteUrl: https://github.com/bioc/a4Classif
RemoteRef: RELEASE_3_23
RemoteSha: 05b1d197dacf4c319b75cad7bbbf72287a2a4b60
NeedsCompilation: no
Packaged: 2026-04-29 18:05:53 UTC; root
Author: Willem Talloen [aut],
  Tobias Verbeke [aut],
  Laure Cougnaud [cre]
Maintainer: Laure Cougnaud <laure.cougnaud@openanalytics.eu>
Built: R 4.6.0; ; 2026-04-29 18:30:14 UTC; unix

# Generated by roxygen2: do not edit by hand

S3method(confusionMatrix,pamClass)
S3method(plot,pamClass)
S3method(plot,rfClass)
S3method(print,topTablePam)
S3method(print,topTableRfClass)
export(ROCcurve)
export(lassoClass)
export(pamClass)
export(rfClass)
exportMethods(topTable)
importFrom(Biobase,exprs)
importFrom(Biobase,featureData)
importFrom(Biobase,featureNames)
importFrom(Biobase,pData)
importFrom(ROCR,performance)
importFrom(ROCR,plot)
importFrom(ROCR,prediction)
importFrom(a4Core,confusionMatrix)
importFrom(a4Core,topTable)
importFrom(glmnet,glmnet)
importFrom(graphics,axis)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(graphics,segments)
importFrom(methods,setMethod)
importFrom(methods,setOldClass)
importFrom(pamr,pamr.confusion)
importFrom(pamr,pamr.cv)
importFrom(pamr,pamr.listgenes)
importFrom(pamr,pamr.train)
importFrom(stats,var)
importFrom(utils,capture.output)
importFrom(utils,packageDescription)
importFrom(varSelRF,varSelRF)

##############################################
### Random Forest using package 'varSelRF' ###
##############################################

#' Classify using Random Forests
#' 
#' Classify using the Random Forest algorithm of Breiman (2001)
#' @param object object containing the expression measurements; currently the
#'  only method supported is one for ExpressionSet objects
#' @param groups character string indicating the column containing the class 
#'  membership
#' @param probe2gene logical; if \code{TRUE} Affymetrix probeset IDs are translated
#'  into gene symbols in the output object; if \code{FALSE} no such translation 
#'  is conducted
#' @return Object of class 'rfClass'
#' @references Breiman, L. (2001), \emph{Random Forests}, Machine Learning 45(1),
#'  5-32.
#' @note topTable and plot methods are available for 'rfClass' objects.
#' @author Tobias Verbeke and Willem Talloen
#' @seealso \code{\link[randomForest]{randomForest}}
#' @keywords models
#' @importFrom Biobase pData exprs featureData featureNames
#' @importFrom varSelRF varSelRF
#' @examples 
#' if(require(ALL)){
#'  data(ALL, package = "ALL")
#'  ALL <- addGeneInfo(ALL)
#'  ALL$BTtype <- as.factor(substr(ALL$BT,0,1))
#'  # select only a subset of the data for computation time reason
#'  ALLSubset <- ALL[sample.int(n = nrow(ALL), size = 100, replace = TRUE), ]
#'  resultRf <- rfClass(object = ALLSubset, groups = "BTtype")
#'  plot(resultRf)
#'  topTable(resultRf, n = 15)
#' }
#' @export
rfClass <- function(object, groups, probe2gene = TRUE){
  labels <- factor(pData(object)[, groups])
  fit <- varSelRF(t(exprs(object)), labels, ntree = 200,
        ntreeIterat = 100,  vars.drop.frac = 0.2, verbose = FALSE)
  
  # transfer annotation
  if (probe2gene){
    fit$gSymbol <- featureData(object)$`SYMBOL`
    names(fit$gSymbol) <- featureNames(object)
  }

  class(fit) <- c("rfClass", class(fit))
  return(fit)
}

#' @importFrom methods setOldClass
setOldClass("rfClass")

#' Top table for \code{rfClass} object
#' @importFrom a4Core topTable
#' @inheritParams a4Core::topTable
#' @return \code{topTableRfClass} object
#' @importFrom methods setMethod
#' @export
setMethod("topTable", 
    "rfClass",
    function(fit, n){
      selGenes <- fit$selected.vars
      numberSelGenes <- length(selGenes)
      topProbes <- selGenes[seq_len(min(n, numberSelGenes))]
      topList <- data.frame(GeneSymbol=fit$gSymbol[topProbes])
      row.names(topList) <- topProbes 
      res <- list(topList = topList, numberSelGenes = numberSelGenes, n = n)
      class(res) <- c("topTableRfClass",class(res))
      return(res)      
    }
)

#' @export
print.topTableRfClass <- function(x,  ...){
  cat("Random forest selected ", x$numberSelGenes, " genes. The top ", x$n, " genes are:\n\n", sep = "")
  print(x$topList, ...)
}

#' @export
#' @method plot rfClass
#' @importFrom graphics par lines segments axis points
plot.rfClass <- function(x, ...){
      size <- x$selec.history$Number.Variables
      MCR0 <- x$selec.history$OOB
      se0 <- x$selec.history$sd.OOB
      
      se <- rev(se0)
      MCR <- rev(MCR0)

      #create plot
      par(mar = c(5, 4, 4, 2) + 0.1)
	  graphics::plot(seq_along(size), MCR, xaxt = "n", col = "blue", cex = 1.2, ylim = c(0.05, (max(MCR)+max(se))),las=1,
          xlab = "number of genes", ylab = "Misclassification error", main = "")
      lines(seq_along(size), MCR, col = "grey")
      
      segments(seq_along(size), MCR - se, seq_along(size), MCR + se, col='blue')
      axis(1, seq_along(size), rev(size), las=2)
      # indicate chosen gene set size
      o <- rev(size) == length(x$selected.vars)
                    # alternatve:  # indicate minimum
                    #              o <- MCR == min(MCR)
      points(min(seq_along(size)[o]), MCR[o][1], pch = "x", cex = 2)
}

#' @importFrom utils packageDescription
.onAttach <- function(libname, pkgname){
  options(error = NULL)
  packageStartupMessage(paste("\na4Classif version ", packageDescription("a4Classif")$Version, 
          "\n", sep = ""))
}

#' Receiver operating curve
#' 
#' A ROC curve plots the fraction of true positives (TPR = true positive rate)
#'  versus the fraction of false positives (FPR = false positive rate) for a binary classifier
#'  when the discrimination threshold is varied. Equivalently, one can also plot
#'  sensitivity versus (1 - specificity).
#' @param object ExpressionSet object for the experiment
#' @param groups String containing the name of the grouping variable. This should be a 
#' the name of a column in the \code{pData} of the \code{expressionSet} object.
#' @param probesetId The probeset ID. These should be stored in the \code{featureNames}
#'  of the \code{expressionSet} object.
#' @param geneSymbol The gene symbol. These should be stored in the column \code{`Gene Symbol`}
#'  in the \code{featureData} of the \code{expressionSet} object.
#' @param main Main title on top of the graph
#' @param probe2gene Boolean indicating whether the probeset should be translated to a gene symbol
#'  (used for the default title of the plot)
#' @param ... Possibility to add extra plot options. See \code{\link{par}}
#' @return a plot is drawn in the current device.
#' prediction object is returned invisibly.
#' @references Some explanation about ROC can be found on 
#' \url{http://en.wikipedia.org/wiki/ROC_curve}
#'  and \url{http://www.anaesthetist.com/mnm/stats/roc/Findex.htm}. 
#' The latter has at the bottom a nice interactive tool 
#' to scroll the cut-off and to see how it affects the FP/TP table and the ROC curve. 
#' @author Willem Talloen
#' @examples 
#' # simulated data set
#' esSim <- simulateData()
#' ROCcurve(probesetId = 'Gene.1', object = esSim, groups = 'type', addLegend = FALSE)
#' @importFrom Biobase exprs featureData featureNames
#' @importFrom ROCR prediction performance plot
#' @export
ROCcurve <- function (object, groups, probesetId = NULL, 
		geneSymbol = NULL, main = NULL, probe2gene = TRUE, ...){
	
	if (!is.null(probesetId) & !is.null(geneSymbol))
		stop("Please provide either a 'probeset' or a 'gene'")
	
	### create gene expression vector
	if (is.null(geneSymbol)){ # probeset given
		probesetId <- as.character(probesetId)     # use names not position !!
		exprGene <- exprs(object)[probesetId, ]
	} else { # gene given
		probesetPos <- which(geneSymbol == featureData(object)$SYMBOL)
		if (!length(probesetPos))
			stop("gene 'gene' does not occur in ExpressionSet 'object'")
		
		probesetId <- featureNames(object)[probesetPos]
		if (length(probesetId) > 1)
			warning(paste("Gene", geneSymbol, "corresponds to", length(probesetId), 
							"probesets; only the first probeset (",probesetId[1],") has been displayed on the plot."))
		exprGene <- exprs(object)[probesetId[1], ] # use names not position !!
	}
	
	labels <- factor(pData(object)[, groups])
	# sort levels of the labels so that the group with on average the lowest values comes first
	rankMeanLabels <- rank(by(exprGene, labels, mean))
	levels(labels) <- levels(labels)[rankMeanLabels]
	
	# prepare title
	if (probe2gene){
		gSymbol <- featureData(object)[probesetId[1],]$SYMBOL
	}
	
	mainTitle <- if (is.null(main)){
				if (probe2gene)
					paste(gSymbol, " (", probesetId[1], ")", sep = "")
				else probesetId[1]
			} else { 
				main 
			}
	
	pred <- ROCR::prediction(predictions = exprGene, labels = labels)
	
	### plot ROC curve (x-axis: fpr, y-axis: tpr)
	perf <- ROCR::performance(pred, "tpr", "fpr")
	ROCR::plot(perf, avg= "threshold", colorize = TRUE, main = mainTitle, lwd = 3)
	invisible(pred)
}

#' Classify using Prediction Analysis for MicroArrays
#' 
#' Classify using the Prediction Analysis for MicroArrays (PAM) algorithm as implemented 
#' in the pamr package
#' @param object object containing the expression measurements; currently the
#'  only method supported is one for ExpressionSet objects
#' @param groups character string indicating the column containing the class membership
#' @param probe2gene logical; if \code{TRUE} Affymetrix probeset IDs are translated
#' into gene symbols; if \code{FALSE} no such translation is conducted
#' @return object of class \code{pamClass}
#' @references
#' Robert Tibshirani, Trevor Hastie, Balasubramanian Narasimhan, and
#'  Gilbert Chu (1999). Diagnosis of multiple cancer types by shrunken
#'  centroids of gene expression.  PNAS 99: 6567-6572.    
#'  Available at \url{www.pnas.org}
#' @references Goehlmann, H. and W. Talloen (2009). Gene Expression Studies Using Affymetrix
#'  Microarrays, Chapman \& Hall/CRC, p. 221.
#' @author Willem Talloen
#' @seealso \code{\link[pamr]{pamr.train}}
#' @keywords models
#' @importFrom Biobase featureNames pData featureData
#' @importFrom pamr pamr.train pamr.cv
#' @examples
#' if(require(ALL)){
#'  data(ALL, package = "ALL")
#'  ALL <- addGeneInfo(ALL)
#'  ALL$BTtype <- as.factor(substr(ALL$BT,0,1))
#'  resultPam <- pamClass(object = ALL, groups = "BTtype")
#'  plot(resultPam)
#'  topTable(resultPam, n = 5)
#'  confusionMatrix(resultPam)
#' }
#' @importFrom utils capture.output
#' @export
pamClass <- function(object, groups, probe2gene = TRUE){
  
  labels <- factor(pData(object)[, groups])
  
  gI <- featureNames(object)
  dat <- list(x = as.matrix(exprs(object)), y = labels, geneid = gI)
  
  co <- capture.output(model <- pamr.train(dat))
  co2 <- capture.output(modelCV <- pamr.cv(model, dat, nfold = 10))
  matModelCV <- data.frame(threshold = format(round(modelCV$threshold, 3)),
      nonzero = format(trunc(modelCV$size)), 
      errors = trunc(modelCV$error * nrow(modelCV$yhat)))
  selectSmallError <- which(matModelCV$errors == min(matModelCV$errors))
  selectSmallErrorFewGenes <- selectSmallError[length(selectSmallError)]
  Delta <- as.numeric(as.character(matModelCV[selectSmallErrorFewGenes, "threshold"]))
  res <- list(pamModel = model, pamCV = modelCV, delta = Delta, exprDat = dat)
  res$featureData <- pData(featureData(object))
  res$probe2gene <- probe2gene
  class(res) <- "pamClass"
  return(res)
}  

#' @importFrom pamr pamr.confusion
#' @importFrom a4Core confusionMatrix
#' @export
confusionMatrix.pamClass <- function(x, ...){
  res <- pamr.confusion(x$pamModel, x$delta, extra = FALSE)
  class(res) <- c("pamClassConfusionTable", class(res))
  return(res)
}

#' @importFrom methods setOldClass
setOldClass("pamClass")

#' Top table for \code{pamClass} object
#' 
#' @importFrom a4Core topTable
#' @importFrom stats var
#' @importFrom pamr pamr.listgenes
#' @inheritParams a4Core::topTable
#' @return \code{topTablePam} object
#' @importFrom methods setMethod
#' @export
setMethod("topTable",
    "pamClass",
    function(fit, n){
      co <- capture.output(listGenes <- pamr.listgenes(fit$pamModel, fit$exprDat, fit$delta,
          fitcv = fit$pamCV, genenames = FALSE))
      if (fit$probe2gene){
        gSymbol <- fit$featureData[listGenes[,'id'], "SYMBOL"]
        listGenes <- data.frame(GeneSymbol = gSymbol, listGenes)
      } else {
        listGenes <- data.frame(listGenes)
      }
      
      rownames(listGenes) <- listGenes[,'id']
      listGenes <- listGenes[, !colnames(listGenes) == 'id']
      
      numberSelGenes <- nrow(listGenes)  
      topList <- listGenes[seq_len(min(n, numberSelGenes)),]
      
      res <- list(topList = topList, numberSelGenes = numberSelGenes, n = n, listGenes = listGenes)
      class(res) <- c("topTablePam", class(res))
      return(res)
    }
)

#' @export
print.topTablePam <- function(x,  ...){
  cat("Pam selected ", x$numberSelGenes, " genes. The top ", x$n, " genes are:\n\n" )
  print(x$topList, ...)
}

#' @export
#' @method plot pamClass
#' @importFrom graphics par lines segments axis points
plot.pamClass <- function(x, ...){
      x <- x$pamCV
      n <- nrow(x$yhat)
      y <- rev(x$y)
      if (!is.null(x$newy)) {
        y <- x$newy[x$sample.subset]
      }
      nc <- length(table(y))
      nfolds <- length(x$folds)
      err <- matrix(NA, ncol = ncol(x$yhat), nrow = nfolds)
      temp <- matrix(y, ncol = ncol(x$yhat), nrow = n)
      ni <- rep(NA, nfolds)
      for (i in seq_len(nfolds)) {
        ii <- x$folds[[i]]
        ni[i] <- length(x$folds[[i]])
        err[i, ] <- apply(temp[ii, ] != x$yhat[ii, ], 2, sum)/ni[i]
      }
      se0 <- sqrt(apply(err, 2, var)/nfolds)
      se <- rev(se0)
      MCR <- rev(x$error)

      par(mar=c(5, 4, 4, 2) + 0.1)
      graphics::plot(seq_along(x$size),MCR,xaxt = "n",col="blue",cex=1.2, ylim = c(0.05, (max(MCR)+max(se))),las=1,
          xlab="number of genes",ylab="Misclassification error",main="")
      lines(seq_along(x$size),MCR,col="grey")
      
      segments(seq_along(x$size), MCR - se, seq_len(length(x$size)), MCR + se, col='blue')
      axis(1,seq_along(x$size), rev(x$size), las=2)
      # indicate minimum
      o <- MCR == min(MCR)
      points(min(seq_along(x$size)[o]), MCR[o][1], pch = "x", cex=2)
}

      

#' Classify using the Lasso
#' @param object object containing the expression measurements; currently the
#' only method supported is one for ExpressionSet objects
#' @param groups character string indicating the column containing the class membership
#' @return object of class \code{glmnet}
#' @references Goehlmann, H. and W. Talloen (2009). Gene Expression Studies Using Affymetrix
#'  Microarrays, Chapman \& Hall/CRC, pp. 183, 205 and 212.
#' @author Willem Talloen
#' @seealso \code{\link[glmnet]{glmnet}}
#' @examples 
#' if (require(ALL)){
#'   data(ALL, package = "ALL")
#'   ALL <- addGeneInfo(ALL)
#'   ALL$BTtype <- as.factor(substr(ALL$BT,0,1))
#' 
#'   resultLasso <- lassoClass(object = ALL, groups = "BTtype")
#'   plot(resultLasso, label = TRUE,
#'     main = "Lasso coefficients in relation to degree of
#'   penalization.")
#'   topTable(resultLasso, n = 15)
#' }
#' @importFrom Biobase exprs pData featureData
#' @importFrom glmnet glmnet
#' @keywords models
#' @export
lassoClass <- function(object, groups){
  labels <- factor(pData(object)[,groups])
  object <- object[,!is.na(labels)]
  labels <- factor(pData(object)[,groups])
  
  fit <- glmnet(t(exprs(object)), labels, family="binomial", alpha = 1)
  fit$featureData <- pData(featureData(object))
  return(fit) 
}

---
title: "Vignette of the a4Classif package"
date: "`r Sys.Date()`"
output: 
  rmarkdown::html_document:
    toc: true
    toc_float:
      collapsed: true
    number_sections: true
vignette: >
  %\VignetteIndexEntry{a4Classif package}
  %\VignetteEngine{knitr::rmarkdown}
  \usepackage[utf8]{inputenc}
---

# Introduction

This document explains the functionalities available in the
**a4Classif** package.

This package contains for classification of Affymetrix microarray data,
stored in an `ExpressionSet`.
This package integrates within the Automated Affymetrix Array Analysis 
suite of packages.

```{r loadLibraries, results = 'hide', echo = FALSE}

	library(a4Classif)
	library(ALL)

```

To demonstrate the functionalities of the package, the `ALL`
dataset is used.
The genes are annotated thanks to the `addGeneInfo` utility function
of the `a4Preproc` package.

```{r loadData}

data(ALL, package = "ALL")
ALL <- addGeneInfo(ALL)
ALL$BTtype <- as.factor(substr(ALL$BT,0,1))

```

# Classify microarray data

## Lasso regression

```{r lassoClassification}

resultLasso <- lassoClass(object = ALL, groups = "BTtype")
plot(resultLasso, 
	label = TRUE, 
	main = "Lasso coefficients in relation to degree of penalization."
)
topTable(resultLasso, n = 15)

```

## PAM regression

```{r pamClassification}

resultPam <- pamClass(object = ALL, groups = "BTtype")
plot(resultPam, 
	main = "Pam misclassification error versus number of genes."
)

topTable(resultPam, n = 15)

confusionMatrix(resultPam)

```

## Random forest

```{r randomForestClassification}

# select only a subset of the data for computation time reason
ALLSubset <- ALL[sample.int(n = nrow(ALL), size = 100, replace = FALSE), ]

resultRf <- rfClass(object = ALLSubset, groups = "BTtype")
plot(resultRf)
topTable(resultRf, n = 15)

```

## ROC curve

```{r rocCurve}

ROCcurve(gene = "ABL1", object = ALL, groups = "BTtype")

```

# Appendix

## Session information

```{r sessionInformation, echo = FALSE}
print(sessionInfo())
```

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lassoClass.R
\name{lassoClass}
\alias{lassoClass}
\title{Classify using the Lasso}
\usage{
lassoClass(object, groups)
}
\arguments{
\item{object}{object containing the expression measurements; currently the
only method supported is one for ExpressionSet objects}

\item{groups}{character string indicating the column containing the class membership}
}
\value{
object of class \code{glmnet}
}
\description{
Classify using the Lasso
}
\examples{
if (require(ALL)){
  data(ALL, package = "ALL")
  ALL <- addGeneInfo(ALL)
  ALL$BTtype <- as.factor(substr(ALL$BT,0,1))

  resultLasso <- lassoClass(object = ALL, groups = "BTtype")
  plot(resultLasso, label = TRUE,
    main = "Lasso coefficients in relation to degree of
  penalization.")
  topTable(resultLasso, n = 15)
}
}
\references{
Goehlmann, H. and W. Talloen (2009). Gene Expression Studies Using Affymetrix
 Microarrays, Chapman \& Hall/CRC, pp. 183, 205 and 212.
}
\seealso{
\code{\link[glmnet]{glmnet}}
}
\author{
Willem Talloen
}
\keyword{models}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pam.R
\name{pamClass}
\alias{pamClass}
\title{Classify using Prediction Analysis for MicroArrays}
\usage{
pamClass(object, groups, probe2gene = TRUE)
}
\arguments{
\item{object}{object containing the expression measurements; currently the
only method supported is one for ExpressionSet objects}

\item{groups}{character string indicating the column containing the class membership}

\item{probe2gene}{logical; if \code{TRUE} Affymetrix probeset IDs are translated
into gene symbols; if \code{FALSE} no such translation is conducted}
}
\value{
object of class \code{pamClass}
}
\description{
Classify using the Prediction Analysis for MicroArrays (PAM) algorithm as implemented 
in the pamr package
}
\examples{
if(require(ALL)){
 data(ALL, package = "ALL")
 ALL <- addGeneInfo(ALL)
 ALL$BTtype <- as.factor(substr(ALL$BT,0,1))
 resultPam <- pamClass(object = ALL, groups = "BTtype")
 plot(resultPam)
 topTable(resultPam, n = 5)
 confusionMatrix(resultPam)
}
}
\references{
Robert Tibshirani, Trevor Hastie, Balasubramanian Narasimhan, and
 Gilbert Chu (1999). Diagnosis of multiple cancer types by shrunken
 centroids of gene expression.  PNAS 99: 6567-6572.    
 Available at \url{www.pnas.org}

Goehlmann, H. and W. Talloen (2009). Gene Expression Studies Using Affymetrix
 Microarrays, Chapman \& Hall/CRC, p. 221.
}
\seealso{
\code{\link[pamr]{pamr.train}}
}
\author{
Willem Talloen
}
\keyword{models}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/randomForest.R
\name{rfClass}
\alias{rfClass}
\title{Classify using Random Forests}
\usage{
rfClass(object, groups, probe2gene = TRUE)
}
\arguments{
\item{object}{object containing the expression measurements; currently the
only method supported is one for ExpressionSet objects}

\item{groups}{character string indicating the column containing the class 
membership}

\item{probe2gene}{logical; if \code{TRUE} Affymetrix probeset IDs are translated
into gene symbols in the output object; if \code{FALSE} no such translation 
is conducted}
}
\value{
Object of class 'rfClass'
}
\description{
Classify using the Random Forest algorithm of Breiman (2001)
}
\note{
topTable and plot methods are available for 'rfClass' objects.
}
\examples{
if(require(ALL)){
 data(ALL, package = "ALL")
 ALL <- addGeneInfo(ALL)
 ALL$BTtype <- as.factor(substr(ALL$BT,0,1))
 # select only a subset of the data for computation time reason
 ALLSubset <- ALL[sample.int(n = nrow(ALL), size = 100, replace = TRUE), ]
 resultRf <- rfClass(object = ALLSubset, groups = "BTtype")
 plot(resultRf)
 topTable(resultRf, n = 15)
}
}
\references{
Breiman, L. (2001), \emph{Random Forests}, Machine Learning 45(1),
 5-32.
}
\seealso{
\code{\link[randomForest]{randomForest}}
}
\author{
Tobias Verbeke and Willem Talloen
}
\keyword{models}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ROC.R
\name{ROCcurve}
\alias{ROCcurve}
\title{Receiver operating curve}
\usage{
ROCcurve(
  object,
  groups,
  probesetId = NULL,
  geneSymbol = NULL,
  main = NULL,
  probe2gene = TRUE,
  ...
)
}
\arguments{
\item{object}{ExpressionSet object for the experiment}

\item{groups}{String containing the name of the grouping variable. This should be a 
the name of a column in the \code{pData} of the \code{expressionSet} object.}

\item{probesetId}{The probeset ID. These should be stored in the \code{featureNames}
of the \code{expressionSet} object.}

\item{geneSymbol}{The gene symbol. These should be stored in the column \code{`Gene Symbol`}
in the \code{featureData} of the \code{expressionSet} object.}

\item{main}{Main title on top of the graph}

\item{probe2gene}{Boolean indicating whether the probeset should be translated to a gene symbol
(used for the default title of the plot)}

\item{...}{Possibility to add extra plot options. See \code{\link{par}}}
}
\value{
a plot is drawn in the current device.
prediction object is returned invisibly.
}
\description{
A ROC curve plots the fraction of true positives (TPR = true positive rate)
 versus the fraction of false positives (FPR = false positive rate) for a binary classifier
 when the discrimination threshold is varied. Equivalently, one can also plot
 sensitivity versus (1 - specificity).
}
\examples{
# simulated data set
esSim <- simulateData()
ROCcurve(probesetId = 'Gene.1', object = esSim, groups = 'type', addLegend = FALSE)
}
\references{
Some explanation about ROC can be found on 
\url{http://en.wikipedia.org/wiki/ROC_curve}
 and \url{http://www.anaesthetist.com/mnm/stats/roc/Findex.htm}. 
The latter has at the bottom a nice interactive tool 
to scroll the cut-off and to see how it affects the FP/TP table and the ROC curve.
}
\author{
Willem Talloen
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pam.R
\name{topTable,pamClass-method}
\alias{topTable,pamClass-method}
\title{Top table for \code{pamClass} object}
\usage{
\S4method{topTable}{pamClass}(fit, n)
}
\arguments{
\item{fit}{object for which to obtain a top table, generally a fit object for a given model class}

\item{n}{number of features (variables) to list in the top table, ranked by importance}
}
\value{
\code{topTablePam} object
}
\description{
Top table for \code{pamClass} object
}
